===============================
cybak-lzma
===============================

.. image:: https://img.shields.io/travis/iansmcf/cybak-lzma.svg
        :target: https://travis-ci.org/iansmcf/cybak-lzma

.. image:: https://img.shields.io/pypi/v/cybak-lzma.svg
        :target: https://pypi.python.org/pypi/cybak-lzma


Python Boilerplate contains all the boilerplate you need to create a Python package.

* Free software: BSD license
* Documentation: https://cybak-lzma.readthedocs.org.

Features
--------

* TODO
